@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -58,17 +58,19 @@ package com.openexchange.crypto;
  */
 public class SimCryptoService implements CryptoService {
 
-    
+
     private String encrypted;
     private String decrypted;
+    private String password;
 
     public SimCryptoService(String encrypted, String decrypted) {
         super();
         this.encrypted = encrypted;
         this.decrypted = decrypted;
     }
-    
+
     public String decrypt(String encryptedPayload, String password) throws CryptoException {
+        this.password = password;
         return decrypted;
     }
 
@@ -77,11 +79,16 @@ public class SimCryptoService implements CryptoService {
     }
 
     public String encrypt(String data, String password) throws CryptoException {
-        return encrypted;
+        this.password = password;
+            return encrypted;
     }
 
     public EncryptedData encrypt(String data, String password, boolean useSalt) throws CryptoException {
         return null;
     }
+    
+    public String getPassword() {
+        return password;
+    }
 
 }
